@@ -1,6 +1,6 @@
 msg <- function(..., startup = FALSE) {
   if (startup) {
-    if (!isTRUE(getOption("yotover.quiet"))) {
+    if (!isTRUE(getOption("censo2017.quiet"))) {
       packageStartupMessage(text_col(...))
     }
   } else {
@@ -30,3 +30,14 @@ in_chk <- function() {
     )
   )
 }
+
+read_table_error <- function(e) {
+  e <- as.character(e)
+  # return(e)
+  msg <- c(
+    sprintf("No esta disponible la tabla %s.", get("tabla", envir = 1)),
+    "\nVerifica que escribiste el nombre correctamente y que instalaste los",
+    "\ndatos con censo_descargar_base()."
+  )
+  stop(msg, call. = FALSE)
+}
